@@ -92,7 +92,6 @@ public class DovecotPushActivator extends HousekeepingActivator {
 
     @Override
     protected void startBundle() throws Exception {
-        Services.setServiceLookup(this);
         DovecotPushConfiguration configuration = new DovecotPushConfiguration();
         configuration.init(this);
 
@@ -110,12 +109,13 @@ public class DovecotPushActivator extends HousekeepingActivator {
         openTrackers();
 
         registerService(DeleteListener.class, new DovecotPushDeleteListener());
+
+        registerService(DovecotPushRESTService.class, new DovecotPushRESTService(this));
     }
 
     @Override
     protected void stopBundle() throws Exception {
         DovecotPushManagerService.dropInstance();
-        Services.setServiceLookup(null);
         super.stopBundle();
     }
 
